handler

package
v0.0.0-...-247ce54 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2024 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AdditiveCipherHandler

type AdditiveCipherHandler struct{}

func (AdditiveCipherHandler) DecryptHandler

func (a AdditiveCipherHandler) DecryptHandler(w http.ResponseWriter, r *http.Request)

func (AdditiveCipherHandler) EncryptHandler

func (a AdditiveCipherHandler) EncryptHandler(w http.ResponseWriter, r *http.Request)

type AffineCipherHandler

type AffineCipherHandler struct{}

func (AffineCipherHandler) DecryptHandler

func (a AffineCipherHandler) DecryptHandler(w http.ResponseWriter, r *http.Request)

func (AffineCipherHandler) EncryptHandler

func (a AffineCipherHandler) EncryptHandler(w http.ResponseWriter, r *http.Request)

type AutokeyCipherHandler

type AutokeyCipherHandler struct{}

func (AutokeyCipherHandler) DecryptHandler

func (a AutokeyCipherHandler) DecryptHandler(w http.ResponseWriter, r *http.Request)

func (AutokeyCipherHandler) EncryptHandler

func (a AutokeyCipherHandler) EncryptHandler(w http.ResponseWriter, r *http.Request)

type MultiplicativeCipherHandler

type MultiplicativeCipherHandler struct{}

func (MultiplicativeCipherHandler) DecryptHandler

func (MultiplicativeCipherHandler) EncryptHandler

type RsaCipherHandler

type RsaCipherHandler struct{}

RsaCipherHandler is a struct that defines the handler for the RSA cipher

func (RsaCipherHandler) DecryptHandler

func (r RsaCipherHandler) DecryptHandler(w http.ResponseWriter, req *http.Request)

func (RsaCipherHandler) EncryptHandler

func (r RsaCipherHandler) EncryptHandler(w http.ResponseWriter, req *http.Request)

func (RsaCipherHandler) GenerateKeyHandler

func (r RsaCipherHandler) GenerateKeyHandler(w http.ResponseWriter, req *http.Request)

type VigenereCipherHandler

type VigenereCipherHandler struct{}

VigenereCipherHandler is a struct that defines the Vigenere cipher handler.

func (VigenereCipherHandler) DecryptHandler

func (v VigenereCipherHandler) DecryptHandler(w http.ResponseWriter, r *http.Request)

func (VigenereCipherHandler) EncryptHandler

func (v VigenereCipherHandler) EncryptHandler(w http.ResponseWriter, r *http.Request)

Jump to